@@ -437,10 +437,16 @@ impl PanelUi {
 #[serde(deny_unknown_fields)]
 pub struct GeneralConfig {
     #[serde(default)]
-    pub show_hidden: Option<bool>,
+    pub enable_mouse: bool,
 
     #[serde(default)]
-    pub read_only: Option<bool>,
+    pub show_hidden: bool,
+
+    #[serde(default)]
+    pub read_only: bool,
+
+    #[serde(default)]
+    pub disable_recover_mode: bool,
 
     #[serde(default)]
     pub cursor: UiElement,
@@ -481,12 +487,12 @@ pub struct GeneralConfig {
 
 impl GeneralConfig {
     /// Get a reference to the general config's show hidden.
-    pub fn show_hidden(&self) -> Option<bool> {
+    pub fn show_hidden(&self) -> bool {
         self.show_hidden
     }
 
     /// Get a reference to the general config's read only.
-    pub fn read_only(&self) -> Option<bool> {
+    pub fn read_only(&self) -> bool {
         self.read_only
     }
 
@@ -549,6 +555,21 @@ impl GeneralConfig {
     pub fn panel_ui(&self) -> &PanelUi {
         &self.panel_ui
     }
+
+    /// Get a reference to the general config's enable mouse.
+    pub fn enable_mouse(&self) -> bool {
+        self.enable_mouse
+    }
+
+    /// Get a reference to the general config's disable recover mode.
+    pub fn disable_recover_mode(&self) -> bool {
+        self.disable_recover_mode
+    }
+
+    /// Set the general config's read only.
+    pub fn set_read_only(&mut self, read_only: bool) {
+        self.read_only = read_only;
+    }
 }
 
 #[derive(Debug, Clone, Default, PartialEq, Serialize, Deserialize)]
