@@ -9,7 +9,10 @@ pub mod event_reader;
 pub mod explorer;
 pub mod input;
 pub mod lua;
+pub mod permissions;
 pub mod pipe_reader;
 pub mod pwd_watcher;
 pub mod runner;
 pub mod ui;
+
+pub use app::runner;
